@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# pylint: disable=star-args, too-many-arguments, fixme
+# pylint: disable=star-args, too-many-arguments, fixme, import-outside-toplevel
 
 # Disable while we have Python 2.x compatability
 # pylint: disable=useless-object-inheritance,bad-mcs-classmethod-argument
@@ -41,6 +41,7 @@ from .utils import really_unicode
 from .xml import (
     XML, ns_tag
 )
+from .data_structure_quirks import apply_resource_quirks
 
 # Due to cyclic import problems, we only import from_didl_string at runtime.
 # from data_structures_entry import from_didl_string
@@ -168,6 +169,9 @@ class DidlResource(object):
             else:
                 return None
 
+        # Check for and fix non-spec compliant behavior in the incoming data
+        element = apply_resource_quirks(element)
+
         content = {}
         # required
         content['protocol_info'] = element.get('protocolInfo')
@@ -457,6 +461,8 @@ class DidlObject(with_metaclass(DidlMetaClass, object)):
         # subclass, ignore it by stripping it from item_class
         if '.#' in item_class:
             item_class = item_class[:item_class.find('.#')]
+        if '#' in item_class:
+            item_class = item_class[:item_class.find('#')]
 
         if item_class != cls.item_class:
             raise DIDLMetadataError(
